@@ -20,7 +20,7 @@ use English                qw(-no_match_vars);
 use Carp                   qw(carp croak);
 use Cwd                    qw();
 
-our $VERSION     = '0.12';
+our $VERSION     = '0.13';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our @EXPORT_TAGS = ( ':all' => \@EXPORT_OK );
@@ -118,9 +118,9 @@ build() {
 [% FI %]
 [% IF is_modulebuild %]
     perl Build.PL --installdirs=vendor --destdir="$pkgdir" &&
-    ./Build &&
-    [% IF skiptest %]#[% FI %]./Build test &&
-    ./Build install;
+    perl Build &&
+    [% IF skiptest %]#[% FI %]perl Build test &&
+    perl Build install;
 [% FI %]
   } || return 1;
 
@@ -129,6 +129,14 @@ build() {
 }
 END_TEMPL
 
+=for Weird "perl Build" Syntax
+We use "perl Build" above instead of the normal "./Build" in order to
+make the yaourt packager happy.  Yaourt runs the PKGBUILD under the /tmp
+directory and makepkg will fail if /tmp is a seperate partition mounted
+with noexec.  Thanks to xenoterracide on the AUR for mentioning the
+problem.
+
+=cut
 
 #----------------------------------------------------------------------
 # CLASS GLOBALS
@@ -307,7 +315,8 @@ Package type must be 'bin' or 'src'};
     my $srcfile_fqp = $status->pkgbase . '/' . $module->package;
     my $pkgfile_fqp = $status->pkgbase . "/$pkgfile";
 
-    my $destdir = $opts{destdir} || $status->destdir;
+    $status->destdir( $opts{destdir} ) if $opts{destdir};
+    my $destdir = $status->destdir;
     $destdir = Cwd::abs_path( $destdir );
     my $destfile_fqp = catfile( $destdir, $pkgfile );
 
@@ -321,11 +330,12 @@ Package type must be 'bin' or 'src'};
 
     $self->create_pkgbuild($self->status->pkgbase);
 
-    # Wrap it up!
+    # Package it up!
+    local $ENV{PKGDEST} = $destdir;
     chdir $status->pkgbase or die "chdir: $OS_ERROR";
     my $makepkg_cmd = join ' ', ( 'makepkg',
                                   # XXX: should we force rebuilding?
-                                  #'-f',
+                                  '-f',
                                   ( $EUID == 0         ? '--asroot'   : () ),
                                   ( $pkg_type eq 'src' ? '--source'   : () ),
                                   ( !$opts{verbose}    ? '>/dev/null' : () ),
@@ -343,11 +353,6 @@ Package type must be 'bin' or 'src'};
         return 0;
     }
 
-    if ( ! rename $pkgfile_fqp, $destfile_fqp ) {
-        error "failed to move $pkgfile to $destfile_fqp: $OS_ERROR";
-        return 0;
-    }
-
     $status->dist($destfile_fqp);
     return $status->created(1);
 }
@@ -475,6 +480,12 @@ sub get_destdir
     return $self->status->destdir;
 }
 
+sub get_pkgpath
+{
+    my $self = shift;
+    return $self->status->dist;
+}
+
 sub get_cpandistdir
 {
     my ($self) = @_;
@@ -773,7 +784,9 @@ sub _prepare_status
                            ( sprintf "%vd", $PERL_VERSION ),
                            'pacman' );
 
-    $status->destdir( $PKGDEST || catdir( $our_base, 'pkg' ) );
+    $status->destdir( $ENV{PKGDEST} ||
+                      $PKGDEST      ||
+                      catdir( $our_base, 'pkg' ) );
 
     my ($pkgver, $pkgname)
         = (  dist_pkgver( $module->package_version ),
